@@ -408,14 +408,12 @@ const v8::Function* v8__ScriptCompiler__CompileFunctionInContext(
     size_t context_extensions_count, const v8::Object** context_extensions,
     v8::ScriptCompiler::CompileOptions options,
     v8::ScriptCompiler::NoCacheReason no_cache_reason) {
-  return maybe_local_to_ptr(
-      v8::ScriptCompiler::CompileFunctionInContext(
-        ptr_to_local(context), source,
-        arguments_count,
-        reinterpret_cast<v8::Local<v8::String>*>(arguments),
-        context_extensions_count,
-        reinterpret_cast<v8::Local<v8::Object>*>(context_extensions),
-        options, no_cache_reason, nullptr));
+  return maybe_local_to_ptr(v8::ScriptCompiler::CompileFunctionInContext(
+      ptr_to_local(context), source, arguments_count,
+      reinterpret_cast<v8::Local<v8::String>*>(arguments),
+      context_extensions_count,
+      reinterpret_cast<v8::Local<v8::Object>*>(context_extensions), options,
+      no_cache_reason, nullptr));
 }
 
 const v8::UnboundScript* v8__ScriptCompiler__CompileUnboundScript(
@@ -867,8 +865,7 @@ int v8__String__Utf8Length(const v8::String& self, v8::Isolate* isolate) {
 }
 
 int v8__String__Write(const v8::String& self, v8::Isolate* isolate,
-                      uint16_t* buffer, int start, int length,
-                      int options) {
+                      uint16_t* buffer, int start, int length, int options) {
   return self.Write(isolate, buffer, start, length, options);
 }
 
@@ -904,8 +901,7 @@ const v8::String* v8__String__NewExternalOneByteStatic(v8::Isolate* isolate,
       isolate, new ExternalStaticOneByteStringResource(data, length)));
 }
 
-class ExternalStaticStringResource
-    : public v8::String::ExternalStringResource {
+class ExternalStaticStringResource : public v8::String::ExternalStringResource {
  public:
   ExternalStaticStringResource(const uint16_t* data, int length)
       : _data(data), _length(length) {}
@@ -934,7 +930,9 @@ bool v8__String__IsExternalTwoByte(const v8::String& self) {
   return self.IsExternalTwoByte();
 }
 bool v8__String__IsOneByte(const v8::String& self) { return self.IsOneByte(); }
-bool v8__String__ContainsOnlyOneByte(const v8::String& self) { return self.ContainsOnlyOneByte(); }
+bool v8__String__ContainsOnlyOneByte(const v8::String& self) {
+  return self.ContainsOnlyOneByte();
+}
 
 const v8::Symbol* v8__Symbol__New(v8::Isolate* isolate,
                                   const v8::String& description) {
@@ -1013,8 +1011,8 @@ void v8__ObjectTemplate__SetInternalFieldCount(const v8::ObjectTemplate& self,
 }
 
 void v8__ObjectTemplate__SetAccessor(const v8::ObjectTemplate& self,
-                                  const v8::Name& key,
-                                  v8::AccessorNameGetterCallback getter) {
+                                     const v8::Name& key,
+                                     v8::AccessorNameGetterCallback getter) {
   ptr_to_local(&self)->SetAccessor(ptr_to_local(&key), getter);
 }
 
@@ -1582,6 +1580,24 @@ void v8__FunctionTemplate__SetClassName(const v8::FunctionTemplate& self,
   ptr_to_local(&self)->SetClassName(ptr_to_local(&name));
 }
 
+void v8__FunctionTemplate__Inherit(const v8::FunctionTemplate& self,
+                                   const v8::FunctionTemplate& parent) {
+  ptr_to_local(&self)->Inherit(ptr_to_local(&parent));
+}
+
+void v8__FunctionTemplate__ReadOnlyPrototype(const v8::FunctionTemplate& self) {
+  ptr_to_local(&self)->ReadOnlyPrototype();
+}
+
+void v8__FunctionTemplate__RemovePrototype(const v8::FunctionTemplate& self) {
+  ptr_to_local(&self)->RemovePrototype();
+}
+
+const v8::ObjectTemplate* v8__FunctionTemplate__PrototypeTemplate(
+    const v8::FunctionTemplate& self) {
+  return local_to_ptr(ptr_to_local(&self)->PrototypeTemplate());
+}
+
 v8::Isolate* v8__FunctionCallbackInfo__GetIsolate(
     const v8::FunctionCallbackInfo<v8::Value>& self) {
   return self.GetIsolate();
@@ -2008,18 +2024,64 @@ v8::StartupData v8__SnapshotCreator__CreateBlob(
   return self->CreateBlob(function_code_handling);
 }
 
-v8::Platform* v8__platform__NewDefaultPlatform() {
-  // TODO(bnoordhuis) Support optional arguments.
-  return v8::platform::NewDefaultPlatform().release();
+v8::Platform* v8__Platform__NewDefaultPlatform(int thread_pool_size,
+                                               bool idle_task_support) {
+  return v8::platform::NewDefaultPlatform(
+             thread_pool_size,
+             idle_task_support ? v8::platform::IdleTaskSupport::kEnabled
+                               : v8::platform::IdleTaskSupport::kDisabled,
+             v8::platform::InProcessStackDumping::kDisabled, nullptr)
+      .release();
 }
 
-v8::Platform* v8__platform__NewSingleThreadedDefaultPlatform() {
-  // TODO(bnoordhuis) Support optional arguments.
-  return v8::platform::NewSingleThreadedDefaultPlatform().release();
+v8::Platform* v8__Platform__NewSingleThreadedDefaultPlatform(
+    bool idle_task_support) {
+  return v8::platform::NewSingleThreadedDefaultPlatform(
+             idle_task_support ? v8::platform::IdleTaskSupport::kEnabled
+                               : v8::platform::IdleTaskSupport::kDisabled,
+             v8::platform::InProcessStackDumping::kDisabled, nullptr)
+      .release();
+}
+
+bool v8__Platform__PumpMessageLoop(v8::Platform* platform, v8::Isolate* isolate,
+                                   bool wait_for_work) {
+  return v8::platform::PumpMessageLoop(
+      platform, isolate,
+      wait_for_work ? v8::platform::MessageLoopBehavior::kWaitForWork
+                    : v8::platform::MessageLoopBehavior::kDoNotWait);
+}
+
+void v8__Platform__RunIdleTasks(v8::Platform* platform, v8::Isolate* isolate,
+                                double idle_time_in_seconds) {
+  v8::platform::RunIdleTasks(platform, isolate, idle_time_in_seconds);
 }
 
 void v8__Platform__DELETE(v8::Platform* self) { delete self; }
 
+two_pointers_t std__shared_ptr__v8__Platform__CONVERT__std__unique_ptr(
+    v8::Platform* unique_ptr) {
+  return make_pod<two_pointers_t>(std::shared_ptr<v8::Platform>(unique_ptr));
+}
+
+v8::Platform* std__shared_ptr__v8__Platform__get(
+    const std::shared_ptr<v8::Platform>& ptr) {
+  return ptr.get();
+}
+
+two_pointers_t std__shared_ptr__v8__Platform__COPY(
+    const std::shared_ptr<v8::Platform>& ptr) {
+  return make_pod<two_pointers_t>(ptr);
+}
+
+void std__shared_ptr__v8__Platform__reset(std::shared_ptr<v8::Platform>* ptr) {
+  ptr->reset();
+}
+
+long std__shared_ptr__v8__Platform__use_count(
+    const std::shared_ptr<v8::Platform>& ptr) {
+  return ptr.use_count();
+}
+
 void v8_inspector__V8Inspector__Channel__BASE__sendResponse(
     v8_inspector::V8Inspector::Channel* self, int callId,
     v8_inspector::StringBuffer* message);
